import { z } from 'zod';
export declare const DotnetReleasesIndexSchema: z.ZodObject<{
    'releases-index': z.ZodArray<z.ZodObject<{
        'channel-version': z.ZodString;
        'latest-release': z.ZodString;
        'latest-release-date': z.ZodDate;
        security: z.ZodBoolean;
        'latest-runtime': z.ZodString;
        'latest-sdk': z.ZodString;
        product: z.ZodUnion<[z.ZodLiteral<".NET Core">, z.ZodLiteral<".NET">]>;
        'support-phase': z.ZodUnion<[z.ZodLiteral<"current">, z.ZodLiteral<"eol">, z.ZodLiteral<"lts">, z.ZodLiteral<"maintenance">, z.ZodLiteral<"preview">, z.ZodLiteral<"rc">]>;
        'eol-date': z.ZodNullable<z.ZodDate>;
        'releases.json': z.ZodString;
    }, "strip", z.ZodTypeAny, {
        'channel-version': string;
        'latest-release': string;
        'latest-release-date': Date;
        security: boolean;
        'latest-runtime': string;
        'latest-sdk': string;
        product: ".NET Core" | ".NET";
        'support-phase': "eol" | "lts" | "rc" | "preview" | "current" | "maintenance";
        'eol-date': Date | null;
        'releases.json': string;
    }, {
        'channel-version': string;
        'latest-release': string;
        'latest-release-date': Date;
        security: boolean;
        'latest-runtime': string;
        'latest-sdk': string;
        product: ".NET Core" | ".NET";
        'support-phase': "eol" | "lts" | "rc" | "preview" | "current" | "maintenance";
        'eol-date': Date | null;
        'releases.json': string;
    }>, "many">;
}, "strip", z.ZodTypeAny, {
    'releases-index': {
        'channel-version': string;
        'latest-release': string;
        'latest-release-date': Date;
        security: boolean;
        'latest-runtime': string;
        'latest-sdk': string;
        product: ".NET Core" | ".NET";
        'support-phase': "eol" | "lts" | "rc" | "preview" | "current" | "maintenance";
        'eol-date': Date | null;
        'releases.json': string;
    }[];
}, {
    'releases-index': {
        'channel-version': string;
        'latest-release': string;
        'latest-release-date': Date;
        security: boolean;
        'latest-runtime': string;
        'latest-sdk': string;
        product: ".NET Core" | ".NET";
        'support-phase': "eol" | "lts" | "rc" | "preview" | "current" | "maintenance";
        'eol-date': Date | null;
        'releases.json': string;
    }[];
}>;
declare const ReleaseSchema: z.ZodObject<{
    'release-date': z.ZodDate;
    'release-version': z.ZodString;
    security: z.ZodBoolean;
    'release-notes': z.ZodString;
    runtime: z.ZodNullable<z.ZodObject<{
        version: z.ZodString;
        'version-display': z.ZodString;
    }, "strip", z.ZodTypeAny, {
        version: string;
        'version-display': string;
    }, {
        version: string;
        'version-display': string;
    }>>;
    sdk: z.ZodNullable<z.ZodObject<{
        version: z.ZodString;
        'version-display': z.ZodString;
    }, "strip", z.ZodTypeAny, {
        version: string;
        'version-display': string;
    }, {
        version: string;
        'version-display': string;
    }>>;
}, "strip", z.ZodTypeAny, {
    runtime: {
        version: string;
        'version-display': string;
    } | null;
    security: boolean;
    'release-date': Date;
    'release-version': string;
    'release-notes': string;
    sdk: {
        version: string;
        'version-display': string;
    } | null;
}, {
    runtime: {
        version: string;
        'version-display': string;
    } | null;
    security: boolean;
    'release-date': Date;
    'release-version': string;
    'release-notes': string;
    sdk: {
        version: string;
        'version-display': string;
    } | null;
}>;
export declare const DotnetReleasesSchema: z.ZodObject<{
    'channel-version': z.ZodString;
    'latest-release': z.ZodString;
    'latest-release-date': z.ZodDate;
    'latest-runtime': z.ZodString;
    'latest-sdk': z.ZodString;
    'support-phase': z.ZodUnion<[z.ZodLiteral<"current">, z.ZodLiteral<"eol">, z.ZodLiteral<"lts">, z.ZodLiteral<"maintenance">, z.ZodLiteral<"preview">, z.ZodLiteral<"rc">]>;
    releases: z.ZodArray<z.ZodObject<{
        'release-date': z.ZodDate;
        'release-version': z.ZodString;
        security: z.ZodBoolean;
        'release-notes': z.ZodString;
        runtime: z.ZodNullable<z.ZodObject<{
            version: z.ZodString;
            'version-display': z.ZodString;
        }, "strip", z.ZodTypeAny, {
            version: string;
            'version-display': string;
        }, {
            version: string;
            'version-display': string;
        }>>;
        sdk: z.ZodNullable<z.ZodObject<{
            version: z.ZodString;
            'version-display': z.ZodString;
        }, "strip", z.ZodTypeAny, {
            version: string;
            'version-display': string;
        }, {
            version: string;
            'version-display': string;
        }>>;
    }, "strip", z.ZodTypeAny, {
        runtime: {
            version: string;
            'version-display': string;
        } | null;
        security: boolean;
        'release-date': Date;
        'release-version': string;
        'release-notes': string;
        sdk: {
            version: string;
            'version-display': string;
        } | null;
    }, {
        runtime: {
            version: string;
            'version-display': string;
        } | null;
        security: boolean;
        'release-date': Date;
        'release-version': string;
        'release-notes': string;
        sdk: {
            version: string;
            'version-display': string;
        } | null;
    }>, "many">;
}, "strip", z.ZodTypeAny, {
    releases: {
        runtime: {
            version: string;
            'version-display': string;
        } | null;
        security: boolean;
        'release-date': Date;
        'release-version': string;
        'release-notes': string;
        sdk: {
            version: string;
            'version-display': string;
        } | null;
    }[];
    'channel-version': string;
    'latest-release': string;
    'latest-release-date': Date;
    'latest-runtime': string;
    'latest-sdk': string;
    'support-phase': "eol" | "lts" | "rc" | "preview" | "current" | "maintenance";
}, {
    releases: {
        runtime: {
            version: string;
            'version-display': string;
        } | null;
        security: boolean;
        'release-date': Date;
        'release-version': string;
        'release-notes': string;
        sdk: {
            version: string;
            'version-display': string;
        } | null;
    }[];
    'channel-version': string;
    'latest-release': string;
    'latest-release-date': Date;
    'latest-runtime': string;
    'latest-sdk': string;
    'support-phase': "eol" | "lts" | "rc" | "preview" | "current" | "maintenance";
}>;
export type DotnetReleasesIndex = z.infer<typeof DotnetReleasesIndexSchema>;
export type DotnetReleases = z.infer<typeof DotnetReleasesSchema>;
export type DotnetRelease = z.infer<typeof ReleaseSchema>;
export {};
