"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.RubyGemsDatasource = void 0;
const tslib_1 = require("tslib");
const error_messages_1 = require("../../../constants/error-messages");
const decorator_1 = require("../../../util/cache/package/decorator");
const url_1 = require("../../../util/url");
const rubyVersioning = tslib_1.__importStar(require("../../versioning/ruby"));
const datasource_1 = require("../datasource");
const get_1 = require("./get");
const versions_datasource_1 = require("./versions-datasource");
class RubyGemsDatasource extends datasource_1.Datasource {
    constructor() {
        super(RubyGemsDatasource.id);
        this.defaultRegistryUrls = ['https://rubygems.org'];
        this.defaultVersioning = rubyVersioning.id;
        this.registryStrategy = 'hunt';
        this.versionsDatasources = {};
        this.internalRubyGemsDatasource = new get_1.InternalRubyGemsDatasource(RubyGemsDatasource.id);
    }
    async getReleases({ packageName, registryUrl, }) {
        // istanbul ignore if
        if (!registryUrl) {
            return null;
        }
        if (!this.versionsDatasources[registryUrl]) {
            this.versionsDatasources[registryUrl] = new versions_datasource_1.VersionsDatasource(RubyGemsDatasource.id, registryUrl);
        }
        try {
            return await this.versionsDatasources[registryUrl].getReleases({
                packageName,
                registryUrl,
            });
        }
        catch (error) {
            if (error.message === error_messages_1.PAGE_NOT_FOUND_ERROR &&
                (0, url_1.parseUrl)(registryUrl)?.hostname !== 'rubygems.org') {
                return this.internalRubyGemsDatasource.getReleases({
                    packageName,
                    registryUrl,
                });
            }
            throw error;
        }
    }
}
RubyGemsDatasource.id = 'rubygems';
tslib_1.__decorate([
    (0, decorator_1.cache)({
        namespace: `datasource-${RubyGemsDatasource.id}`,
        key: ({ registryUrl, packageName }) => 
        // TODO: types (#7154)
        /* eslint-disable @typescript-eslint/restrict-template-expressions */
        `${registryUrl}/${packageName}`,
    })
], RubyGemsDatasource.prototype, "getReleases", null);
exports.RubyGemsDatasource = RubyGemsDatasource;
//# sourceMappingURL=index.js.map